# 🦕 nanosaur cli
<!-- SOCIAL START -->
[![Sponsor](https://img.shields.io/badge/Sponsor-30363D?logo=GitHub-Sponsors&logoColor=#white)](https://github.com/sponsors/rbonghi) [![Discord](https://img.shields.io/discord/797461428646707211?style=social&logo=discord&label=Discord)](https://discord.gg/rCHgeUpUj9) [![GitHub rnanosaur stars](https://img.shields.io/github/stars/rnanosaur?style=social)](https://github.com/rnanosaur) [![GitHub rbonghi followers](https://img.shields.io/github/followers/rbonghi?label=rbonghi)](https://github.com/rbonghi) [![LinkedIn](https://img.shields.io/badge/LinkedIn:-raffaello--bonghi-0077B5?style=social)](https://www.linkedin.com/in/raffaello-bonghi) [![robo.panther](https://img.shields.io/badge/Follow:-robo.panther-E4405F?style=social&logo=instagram)](https://www.instagram.com/robo.panther)
<!-- SOCIAL END -->
<!-- INTRO START -->
**nanosaur** The smallest [NVIDIA Jetson](https://developer.nvidia.com/buy-jetson) dinosaur robot, **open-source**, fully **3D printable**, based on [**ROS 2**](https://www.ros.org/) & [**Isaac ROS**](https://developer.nvidia.com/isaac-ros-gems).

*Designed & made by [Raffaello Bonghi](https://rnext.it)*

[![nanosaur](https://nanosaur.ai/assets/images/banner.jpg)](https://nanosaur.ai)

Meet nanosaur:

* 🦕 Website: [nanosaur.ai](https://nanosaur.ai)
* 🦄 Do you need any help? [Discord](https://discord.gg/rCHgeUpUj9)
* 🧰 For technical details, follow [wiki](https://github.com/rnanosaur/nanosaur/wiki)
* 🐳 nanosaur [Docker Hub](https://hub.docker.com/u/nanosaur)
* ⁉️ Something wrong? Open an [issue](https://github.com/rnanosaur/nanosaur/issues)
<!-- INTRO END -->
<!-- CI START -->
## CI & CD

| 📦 package | 🏗️ CI | Downloads | Health |
|:----------:|:-----:|:---------:|:------:|
| [![PyPI - Version](https://img.shields.io/pypi/v/nanosaur?label=nanosaur)](https://badge.fury.io/py/nanosaur) | [![Lint and Fix](https://github.com/rnanosaur/nanosaur_pkg/actions/workflows/flake8-lint.yml/badge.svg)](https://github.com/rnanosaur/nanosaur_pkg/actions/workflows/flake8-lint.yml) | [![PyPI - Downloads](https://img.shields.io/pypi/dm/nanosaur)](https://pypistats.org/packages/nanosaur) | [![nanosaur](https://snyk.io/advisor/python/nanosaur/badge.svg)](https://snyk.io/advisor/python/nanosaur) |

|    | 🐳 Image | 🏗️ CI | Downloads | Size |
|:-:|:-------:|:-----:|:---------:|:----:|
| 🦕 | [nanosaur/nanosaur:simulation](https://hub.docker.com/r/nanosaur/nanosaur) | TODO | [![Docker Pulls](https://img.shields.io/docker/pulls/nanosaur/nanosaur)](https://hub.docker.com/r/nanosaur/nanosaur) | [![Docker Image Size (tag)](https://img.shields.io/docker/image-size/nanosaur/nanosaur/simulation)](https://hub.docker.com/r/nanosaur/nanosaur) |
| 🖼️ | [nanosaur/perception:simulation](https://hub.docker.com/r/nanosaur/perception) | TODO | [![Docker Pulls](https://img.shields.io/docker/pulls/nanosaur/perception)](https://hub.docker.com/r/nanosaur/perception) | [![Docker Image Size (tag)](https://img.shields.io/docker/image-size/nanosaur/perception/simulation)](https://hub.docker.com/r/nanosaur/perception) |
| 👨‍💻 | [nanosaur/simulation:isaac-sim](https://hub.docker.com/r/nanosaur/simulation) | TODO | [![Docker Pulls](https://img.shields.io/docker/pulls/nanosaur/simulation)](https://hub.docker.com/r/nanosaur/simulation) | [![Docker Image Size (tag)](https://img.shields.io/docker/image-size/nanosaur/simulation/isaac-sim)](https://hub.docker.com/r/nanosaur/simulation) |
| 👨‍💻 | [nanosaur/simulation:gazebo](https://hub.docker.com/r/nanosaur/simulation) | TODO | [![Docker Pulls](https://img.shields.io/docker/pulls/nanosaur/simulation)](https://hub.docker.com/r/nanosaur/simulation) | [![Docker Image Size (tag)](https://img.shields.io/docker/image-size/nanosaur/simulation/gazebo)](https://hub.docker.com/r/nanosaur/simulation) |

Website: [![pages-build-deployment](https://github.com/rnanosaur/rnanosaur.github.io/actions/workflows/pages/pages-build-deployment/badge.svg)](https://github.com/rnanosaur/rnanosaur.github.io/actions/workflows/pages/pages-build-deployment)
<!-- CI END -->
## Description

Nanosaur is a small, open-source robotic platform designed for educational and research purposes. This package contains all the necessary software to operate and control the Nanosaur robot.

## Develop

Install this package in develop mode

```console
mkdir -p $HOME/nanosaur
cd $HOME/nanosaur
python3 -m venv .venv
source .venv/bin/activate
pip install -e nanosaur_cli[dev]
```

Test this package

```console
nanosaur info
```

<!-- LICENSE START -->
## License

* All code is Under license [MIT](LICENSE)

For more information about this project, please follow [nanosaur.ai/about](https://nanosaur.ai/about/#license)
<!-- LICENSE END -->
<!-- CREDITS START -->
## Contact Information

If you have any questions or inquiries, please contact us at [raffaello@nanosaur.ai](mailto:raffaello@nanosaur.ai).
<!-- CREDITS END -->
